==> ToolChain_STM32_1.0.38.tar.bz: ToolChain_STM32_1.0.38/Examples/example_leds.c <==
/*{ Template_FreeRTOS::.c ************************************************
 
  leds_start() spawns thread taskBrightness()

  taskBrightness()
      Defines brightness of led as Ton / (Ton + Toff)
      spawns thread taskControlLed()
      while (1) {
        while (Ton < 100) { Ton++; Toff--; }
        while (Ton >   0) { Ton--; Toff++; }
      }

  taskControlLed()
      while (1) {
        switch on LED
        wait for Ton
        switch off LED
        wait for Toff
      }

}*/

#include "example_leds.h"

//{ Function definitions *************************************************


void leds_initPorts() {

// enable clocks to all used ports (other clocks are enabled by initPort() automatically)
RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO,  ENABLE);
#if defined (STM32F10X_LD_VL) || defined (STM32F10X_MD_VL)
RCC_ADCCLKConfig(RCC_PCLK2_Div2);  // ADCCLK = PCLK2/2
#else
RCC_ADCCLKConfig(RCC_PCLK2_Div4);  // ADCCLK = PCLK2/4
#endif
RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1,   ENABLE);
RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE);

/*{ Example code

initADC(&AIN_ParallelSwitches, ADC_Channel_15);
ADC_ResetCalibration(ADC1);                  // Enable ADC1 reset calibaration register
while(ADC_GetResetCalibrationStatus(ADC1));  // wait for end of ADC1 reset calibration register
ADC_StartCalibration(ADC1);                  // Start ADC1 calibaration
while(ADC_GetCalibrationStatus(ADC1));       // wait for end of ADC1 calibration

// Start ADC1 Software Conversion
ADC_SoftwareStartConvCmd(ADC1, ENABLE);
}Example code*/
}
void leds_start() {
    leds_initPorts();

    xTaskCreate(taskBrightness,                          // function to start as thread
                (const signed char*) "taskBrightness",   // thread name (just for debugging)
                (size_t) configMINIMAL_STACK_SIZE,       // stack size
                (void *) NULL,                          // passed as argument to taskBrightness()
                (unsigned portBASE_TYPE) 1,              // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                      // can return a handle to created task
               );
}
ConfigLED_t* setLedGPIO(ConfigLED_t* ConfigLED, GPIO_TypeDef* GPIOx, u32_t Pin) {
    ConfigLED->GPIOx = GPIOx;
    ConfigLED->Pin   = Pin;
    return ConfigLED;
}
void reloadWatchdog() {
#ifdef EXTENSION_500_ttc_watchdogs    
    if (1) // activate if watchdog1 has been initialized 
      ttc_reload_Watchdog1();
#endif
}
void taskBrightness(void *pvParameters) {

    ConfigLED_t ConfigLED = { PB_LED1, 100, 0 };
    xTaskCreate(taskControlLed,                          // function to start as thread
                (const signed char*) "taskControlLed",   // thread name (just for debugging)
                (size_t) configMINIMAL_STACK_SIZE, // stack size
                (void *) &ConfigLED,               // passed as argument to taskControlLed()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
                );

    while (1) {
        while (ConfigLED.OnPeriod > 0) {
            reloadWatchdog();
            ConfigLED.OnPeriod--;
            ConfigLED.OffPeriod++;
            mSleep(10);
        }
        while (ConfigLED.OnPeriod < 100) {
            reloadWatchdog();
            ConfigLED.OnPeriod++;
            ConfigLED.OffPeriod--;
            mSleep(10);
        }
    }
}
void taskControlLed(void *pvParameters) {
    ConfigLED_t *ConfigLED = (ConfigLED_t*) pvParameters;
    if (ConfigLED != NULL) {

        initPort(ConfigLED->GPIOx, ConfigLED->Pin, GPIO_Mode_Out_PP);

        while (1) {
            portSet(ConfigLED->GPIOx, ConfigLED->Pin);
            uSleep(ConfigLED->OnPeriod);
            portClr(ConfigLED->GPIOx, ConfigLED->Pin);
            uSleep(ConfigLED->OffPeriod);
        }
    }
}

//} Function definitions

==> ToolChain_STM32_1.0.42.tar.bz: ToolChain_STM32_1.0.42/Examples/example_leds.c <==
/*{ Template_FreeRTOS::.c ************************************************
 
  leds_start() spawns thread taskBrightness()

  taskBrightness()
      Defines brightness of led as Ton / (Ton + Toff)
      spawns thread taskControlLed()
      while (1) {
        while (Ton < 100) { Ton++; Toff--; }
        while (Ton >   0) { Ton--; Toff++; }
      }

  taskControlLed()
      while (1) {
        switch on LED
        wait for Ton
        switch off LED
        wait for Toff
      }

}*/

#include "example_leds.h"

//{ Function definitions *************************************************


void leds_initPorts() {

// enable clocks to all used ports (other clocks are enabled by stm32_initPort() automatically)
RCC_APB2PeriphClockCmd(RCC_APB2Periph_AFIO,  ENABLE);
#if defined (STM32F10X_LD_VL) || defined (STM32F10X_MD_VL)
RCC_ADCCLKConfig(RCC_PCLK2_Div2);  // ADCCLK = PCLK2/2
#else
RCC_ADCCLKConfig(RCC_PCLK2_Div4);  // ADCCLK = PCLK2/4
#endif
RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1,   ENABLE);
RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE);

/*{ Example code

initADC(&AIN_ParallelSwitches, ADC_Channel_15);
ADC_ResetCalibration(ADC1);                  // Enable ADC1 reset calibaration register
while(ADC_GetResetCalibrationStatus(ADC1));  // wait for end of ADC1 reset calibration register
ADC_StartCalibration(ADC1);                  // Start ADC1 calibaration
while(ADC_GetCalibrationStatus(ADC1));       // wait for end of ADC1 calibration

// Start ADC1 Software Conversion
ADC_SoftwareStartConvCmd(ADC1, ENABLE);
}Example code*/
}
void leds_start() {
    leds_initPorts();

    xTaskCreate(taskBrightness,                          // function to start as thread
                (const signed char*) "taskBrightness",   // thread name (just for debugging)
                (size_t) configMINIMAL_STACK_SIZE,       // stack size
                (void *) NULL,                          // passed as argument to taskBrightness()
                (unsigned portBASE_TYPE) 1,              // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                      // can return a handle to created task
               );
}
void reloadWatchdog() {
#ifdef EXTENSION_500_ttc_watchdogs    
    if (1) // activate if watchdog1 has been initialized 
      ttc_reload_Watchdog1();
#endif
}
void taskBrightness(void *pvParameters) {
    pvParameters = pvParameters; // avoids warning: unused parameter 'pvParameters'
    
    ConfigLED_t ConfigLED;
    ConfigLED.OnPeriod  = 100;
    ConfigLED.OffPeriod = 0;
    ttc_initPort(&(ConfigLED.Port), TTC_LED1, tgm_output_push_pull);

    xTaskCreate(taskControlLed,                          // function to start as thread
                (const signed char*) "taskControlLed",   // thread name (just for debugging)
                (size_t) configMINIMAL_STACK_SIZE, // stack size
                (void *) &ConfigLED,               // passed as argument to taskControlLed()
                (unsigned portBASE_TYPE) 1,        // task priority (higher values mean more process time)
                (xTaskHandle*) NULL                // can return a handle to created task
               );

    while (1) {
        while (ConfigLED.OnPeriod > 0) {
            reloadWatchdog();
            ConfigLED.OnPeriod--;
            ConfigLED.OffPeriod++;
            mSleep(10);
        }
        while (ConfigLED.OnPeriod < 100) {
            reloadWatchdog();
            ConfigLED.OnPeriod++;
            ConfigLED.OffPeriod--;
            mSleep(10);
        }
    }
}
void taskControlLed(void *pvParameters) {
    ConfigLED_t *ConfigLED = (ConfigLED_t*) pvParameters;
    if (ConfigLED != NULL) {

        ttc_Port_t* Port = &(ConfigLED->Port);

        while (1) {
            ttc_portSet(Port);
            uSleep(ConfigLED->OnPeriod);
            ttc_portClr(Port);
            uSleep(ConfigLED->OffPeriod);
        }
    }
}

//} Function definitions
